Crate tnodetree

Crate tnodetree 

Structs

Node
Node - contains the item, its relative transform, its absolute transform and a list of its children.
NodeIter
NodeKey
Node Identifier!
NodeTree
Node Tree - generic over I, the item type, and T, the transform type. Stores nodes in a dense slot map from slotmap, and needs a root identifier.